# Calendar fact

Taken from [xkcd.com/1930](https://xkcd.com/1930/), this command generates
calendar facts. Useful for MODs, head or foot lines in apps etc.

## Installation

Install by running:
```shell
pip install calendar-fact
```

## Usage

Run:
```shell
calendar-fact
```

## License

The code is released under the MIT license.

The texts are released under the CC-BY-NC 2.5 license as explained at
[XKCD's license](https://xkcd.com/license.html) page.
